package com.displaynone.acss.ui.init

import android.util.Log
import androidx.lifecycle.ViewModel
import androidx.lifecycle.viewModelScope
import com.displaynone.acss.components.auth.models.user.UserServiceST
import com.displaynone.acss.components.auth.models.user.repository.dto.UserDTO
import com.displaynone.acss.components.init.models.InitServiceST
import com.displaynone.acss.ui.profile.ProfileViewModel.State
import kotlinx.coroutines.flow.MutableStateFlow
import kotlinx.coroutines.flow.asStateFlow
import kotlinx.coroutines.launch

class InitFragmentViewModel: ViewModel()  {
    val _state = MutableStateFlow<State>(State.Loading)
    val state = _state.asStateFlow()
    fun pingServer() {
        viewModelScope.launch {
            InitServiceST.getInstance().ping().fold(
                onSuccess = { _state.emit(State.Show(true)) },
                onFailure = {
                    _state.emit(State.Show(false))
                    Log.d("InitFragmentViewModel", "failed to ping") }
            )
        }
    }

    fun updateUserInfo() {
        viewModelScope.launch {
            UserServiceST.getInstance().getInfo().fold(
                onSuccess = { data ->
                    _state.emit(State.Update(data))
                },
                onFailure = { error ->
                    _state.emit(State.Error(error.message.toString()))
                    Log.d("InitFragmentViewModel", "failed to update user info ${error.message}")
                }
            )
        }
    }
    sealed interface State {
        data object Loading : State
        data class Show(
            val item: Boolean
        ) : State
        data class Update(
            val item: UserDTO
        ) : State
        data class Error(
            val errorMessage: String
        ) : State
    }
}